# Usage Example

from enstools.feature.pipeline import FeaturePipeline
from enstools.feature.identification.overlap_example import OverlapIdentificationExample
from enstools.feature.tracking.template_object_compare import TrackingCompareTemplate
from enstools.feature.tracking.overlap_tracking import OverlapTracking
from enstools.feature.identification._proto_gen import overlap_example_pb2
from os.path import expanduser
from enstools.feature.util.graph import DataGraph

# set the pb_reference to the compiled pb2.py file (see proto_gen directory)
pipeline = FeaturePipeline(overlap_example_pb2, processing_mode='3d')

# change this to an identification strategy that actually does something: existing one or implement your own
i_strat = OverlapIdentificationExample()  # set the Identification strategy
t_strat = OverlapTracking(field_name='identified_areas')  # set the tracking strategy

pipeline.set_identification_strategy(i_strat)
pipeline.set_tracking_strategy(t_strat)  # or None as argument if no tracking

path = expanduser(
    "~") + '/phd/data/tracked/feature/enstools_feature_test.nc'  # ERA5/vietnam/t0_glob.nc' #  set data path(s) here
out_data_path = path[:-3] + '_id.nc'
out_json_path = path[:-3] + '_desc.json'
out_graph_path = path[:-3] + '_graph.json'
pipeline.set_data_path(path)

# execute pipeline
pipeline.execute()

od = pipeline.get_object_desc()  # identified objects, and graph-structure if tracking done

for set in od.sets:  # for each set, e.g. each ensemble member, or each level

    graph = DataGraph(set.graph, overlap_example_pb2)  # get the data graph for this set

    for track in set.tracks: # for each identified track (run generate_tracks beforehand)
        single_track_graph = DataGraph(track, overlap_example_pb2)  # track as data graph (basically subgraph of above)
        # single_track_graph.get_parents(some node...)
        # single_track_graph.get_children(some node...)
        

pipeline.save_result(description_type='json', description_path=out_graph_path,
                     dataset_path=out_data_path)  # dataset_path=...
